-- ==================================================
--	CRIA A TABELA DE LAUDO_DEFEITO
-- ==================================================
CREATE TABLE ROMANEIO_GARANTIA
(
    ID                     INT IDENTITY (1, 1) NOT NULL,
    CADASTRADO_POR         VARCHAR(60),
    DATA_CADASTRO          DATETIME            NOT NULL,
    ULTIMA_MODIFICACAO_POR VARCHAR(60),
    DATA_ULTIMA_ALTERACAO  DATETIME,
    OBSERVACAO_LOGISTICA   VARCHAR(255),
    OBSERVACAO_GARANTIA    VARCHAR(255),
    STATUS                 VARCHAR(14)        NOT NULL,
    DATA_TRANSPORTE        DATETIME,
    DATA_ENTREGA           DATETIME,
    DELETADO               BIT,
    CONSTRAINT PK_ROMANEIO_GARANTIA PRIMARY KEY (ID)
);

-- ==================================================
--	ALTERAR A TABELA DE PRE_NOTA
-- ==================================================
ALTER TABLE PRE_NOTA ADD
    LAUDO_PRIORITARIO BIT,
    ID_ROMANEIO_GARANTIA INT CONSTRAINT FK_PRE_NOTA_ON_ROMANEIO_GARANTIA FOREIGN KEY REFERENCES ROMANEIO_GARANTIA (ID);

-- ==================================================
--	CRIA A TABELA DE LAUDO_DEFEITO
-- ==================================================
CREATE TABLE LAUDO_DEFEITO
(
    ID INT NOT NULL IDENTITY(1,1) CONSTRAINT PK_LAUDO_DEFEITO PRIMARY KEY,
    NOME                   VARCHAR(100) NOT NULL,
    STATUS                 VARCHAR(10) NOT NULL,
    DESCRICAO              VARCHAR(255),
    REPROVAR_QUANTIDADE    BIT,
    DELETADO               BIT,
    CADASTRADO_POR         VARCHAR(60),
    ULTIMA_MODIFICACAO_POR VARCHAR(60),
    DATA_CADASTRO          DATETIME NOT NULL,
    DATA_ULTIMA_ALTERACAO  DATETIME,
    CONSTRAINT UC_LAUDO_DEFEITO_NOME UNIQUE (NOME)
);

-- ==================================================
--	CRIA A TABELA DE LAUDO
-- ==================================================
CREATE TABLE LAUDO (
    ID INT NOT NULL IDENTITY(1,1) CONSTRAINT PK_LAUDO PRIMARY KEY,
    STATUS                  VARCHAR(20) NOT NULL,
    QUANTIDADE_TOTAL        INT,
    QUANTIDADE_APROVADA     INT,
    QUANTIDADE_REPROVADA    INT,
    VALOR_TOTAL             DECIMAL(18, 2),
    VALOR_APROVADO          DECIMAL(18, 2),
    VALOR_REPROVADO         DECIMAL(18, 2),
    OBSERVACAO              VARCHAR(510),
    DATA_VENCIMENTO         DATE,
    DELETADO                BIT,
    CADASTRADO_POR          VARCHAR(60),
    ULTIMA_MODIFICACAO_POR  VARCHAR(60),
    DATA_CADASTRO           DATETIME NOT NULL,
    DATA_ULTIMA_ALTERACAO   DATETIME,
    ID_PRE_NOTA INT CONSTRAINT FK_LAUDO_ON_PRE_NOTA FOREIGN KEY REFERENCES PRE_NOTA(ID)
);

-- ==================================================
--	CRIA A TABELA DE LAUDO_IMAGEM
-- ==================================================
CREATE TABLE LAUDO_IMAGEM
(
    ID_LAUDO               INT NOT NULL,
    ID_ARQUIVO             BINARY(16) NOT NULL,
    TITULO                 VARCHAR(100),
    STATUS                 VARCHAR(10),
    DESCRICAO              VARCHAR(500),
    EXIBIR_PARA_CLIENTE    BIT,
    DELETADO               BIT,
    CADASTRADO_POR         VARCHAR(60),
    ULTIMA_MODIFICACAO_POR VARCHAR(60),
    DATA_CADASTRO          DATETIME NOT NULL,
    DATA_ULTIMA_ALTERACAO  DATETIME,
    CONSTRAINT PK_LAUDO_IMAGEM PRIMARY KEY (ID_LAUDO, ID_ARQUIVO),
    CONSTRAINT FK_LAUDO_IMAGEM_ON_LAUDO FOREIGN KEY (ID_LAUDO) REFERENCES LAUDO(ID),
    CONSTRAINT FK_LAUDO_IMAGEM_ON_ARQUIVO FOREIGN KEY (ID_ARQUIVO) REFERENCES ARQUIVO(ID)
);




-- ==================================================
--	CRIA A TABELA DE LAUDO_ITEM
-- ==================================================
CREATE TABLE LAUDO_ITEM
(
    ID INT NOT NULL IDENTITY(1,1) CONSTRAINT PK_LAUDO_ITEM PRIMARY KEY,
    ITEM                            INT,
    QUANTIDADE_TOTAL                INT,
    QUANTIDADE_APROVADA             INT,
    QUANTIDADE_REPROVADA            INT,
    PRECO_VENDA                     DECIMAL(18, 2),
    PRECO_TOTAL                     DECIMAL(18, 2),
    PRECO_TOTAL_APROVADA            DECIMAL(18, 2),
    PRECO_TOTAL_REPROVADA           DECIMAL(18, 2),
    ICMS_VALOR_TOTAL                DECIMAL(18, 2),
    ICMS_VALOR_APROVADA             DECIMAL(18, 2),
    ICMS_VALOR_REPROVADA            DECIMAL(18, 2),
    ICMS_ALIQUOTA                   DECIMAL(18, 2),
    ICMS_BASE_TOTAL                 DECIMAL(18, 2),
    ICMS_BASE_APROVADA              DECIMAL(18, 2),
    ICMS_BASE_REPROVADA             DECIMAL(18, 2),
    DIFAL_VALOR_TOTAL               DECIMAL(18, 2),
    DIFAL_VALOR_APROVADA            DECIMAL(18, 2),
    DIFAL_VALOR_REPROVADA           DECIMAL(18, 2),
    PIS_VALOR_TOTAL                 DECIMAL(18, 2),
    PIS_VALOR_APROVADA              DECIMAL(18, 2),
    PIS_VALOR_REPROVADA             DECIMAL(18, 2),
    PIS_ALIQUOTA                    DECIMAL(18, 2),
    PIS_BASE_TOTAL                  DECIMAL(18, 2),
    PIS_BASE_APROVADA               DECIMAL(18, 2),
    PIS_BASE_REPROVADA              DECIMAL(18, 2),
    COFINS_VALOR_TOTAL              DECIMAL(18, 2),
    COFINS_VALOR_APROVADA           DECIMAL(18, 2),
    COFINS_VALOR_REPROVADA          DECIMAL(18, 2),
    COFINS_ALIQUOTA                 DECIMAL(18, 2),
    COFINS_BASE_TOTAL               DECIMAL(18, 2),
    COFINS_BASE_APROVADA            DECIMAL(18, 2),
    COFINS_BASE_REPROVADA           DECIMAL(18, 2),
    IPI_VALOR_TOTAL                 DECIMAL(18, 2),
    IPI_VALOR_APROVADA              DECIMAL(18, 2),
    IPI_VALOR_REPROVADA             DECIMAL(18, 2),
    IPI_ALIQUOTA                    DECIMAL(18, 2),
    IPI_BASE_TOTAL                  DECIMAL(18, 2),
    IPI_BASE_APROVADA               DECIMAL(18, 2),
    IPI_BASE_REPROVADA              DECIMAL(18, 2),
    ST_VALOR_TOTAL                  DECIMAL(18, 2),
    ST_VALOR_APROVADA               DECIMAL(18, 2),
    ST_VALOR_REPROVADA              DECIMAL(18, 2),
    ST_BASE_TOTAL                   DECIMAL(18, 2),
    ST_BASE_APROVADA                DECIMAL(18, 2),
    ST_BASE_REPROVADA               DECIMAL(18, 2),
    SUFRAMA_VALOR_TOTAL             DECIMAL(18, 2),
    SUFRAMA_VALOR_APROVADA          DECIMAL(18, 2),
    SUFRAMA_VALOR_REPROVADA         DECIMAL(18, 2),
    SEGURO_VALOR_TOTAL              DECIMAL(18, 2),
    SEGURO_VALOR_APROVADA           DECIMAL(18, 2),
    SEGURO_VALOR_REPROVADA          DECIMAL(18, 2),
    DESCONTO_VALOR_TOTAL            DECIMAL(18, 2),
    DESCONTO_VALOR_APROVADA         DECIMAL(18, 2),
    DESCONTO_VALOR_REPROVADA        DECIMAL(18, 2),
    OUTRAS_DESPESAS_VALOR_TOTAL     DECIMAL(18, 2),
    OUTRAS_DESPESAS_VALOR_APROVADA  DECIMAL(18, 2),
    OUTRAS_DESPESAS_VALOR_REPROVADA DECIMAL(18, 2),
    VALOR_FRETE_TOTAL               DECIMAL(18, 2),
    VALOR_FRETE_APROVADA            DECIMAL(18, 2),
    VALOR_FRETE_REPROVADA           DECIMAL(18, 2),
    VALOR_BRUTO_TOTAL               DECIMAL(18, 2),
    VALOR_BRUTO_APROVADA            DECIMAL(18, 2),
    VALOR_BRUTO_REPROVADA           DECIMAL(18, 2),
    CADASTRADO_POR                  VARCHAR(60),
    ULTIMA_MODIFICACAO_POR          VARCHAR(60),
    DATA_CADASTRO                   DATETIME NOT NULL,
    DATA_ULTIMA_ALTERACAO           DATETIME,
    DELETADO                        BIT,
    ID_LAUDO                        INT NOT NULL CONSTRAINT FK_LAUDO_ITEM_ON_LAUDO FOREIGN KEY REFERENCES LAUDO(ID),
    ID_PRE_NOTA_ITEM                INT NOT NULL CONSTRAINT FK_LAUDO_ITEM_ON_PRE_NOTA_ITEM FOREIGN KEY REFERENCES PRE_NOTA_ITEM(ID),
    CONSTRAINT UC_LAUDO_ITEM_ID_PRE_NOTA_ITEM UNIQUE (ID_PRE_NOTA_ITEM)
);


-- ==================================================
--	CRIA A TABELA DE LAUDO_SUB_ITEM
-- ==================================================
CREATE TABLE LAUDO_SUB_ITEM
(
    ID                              INT NOT NULL IDENTITY (1, 1) CONSTRAINT PK_LAUDO_SUB_ITEM PRIMARY KEY,
    LOTE                            VARCHAR(100),
    QUANTIDADE_TOTAL                INT,
    QUANTIDADE_APROVADA             INT,
    QUANTIDADE_REPROVADA            INT,
    PRECO_VENDA                     DECIMAL(18, 2),
    PRECO_TOTAL                     DECIMAL(18, 2),
    PRECO_TOTAL_APROVADA            DECIMAL(18, 2),
    PRECO_TOTAL_REPROVADA           DECIMAL(18, 2),
    ICMS_VALOR_TOTAL                DECIMAL(18, 2),
    ICMS_VALOR_APROVADA             DECIMAL(18, 2),
    ICMS_VALOR_REPROVADA            DECIMAL(18, 2),
    ICMS_ALIQUOTA                   DECIMAL(18, 2),
    ICMS_BASE_TOTAL                 DECIMAL(18, 2),
    ICMS_BASE_APROVADA              DECIMAL(18, 2),
    ICMS_BASE_REPROVADA             DECIMAL(18, 2),
    DIFAL_VALOR_TOTAL               DECIMAL(18, 2),
    DIFAL_VALOR_APROVADA            DECIMAL(18, 2),
    DIFAL_VALOR_REPROVADA           DECIMAL(18, 2),
    PIS_VALOR_TOTAL                 DECIMAL(18, 2),
    PIS_VALOR_APROVADA              DECIMAL(18, 2),
    PIS_VALOR_REPROVADA             DECIMAL(18, 2),
    PIS_ALIQUOTA                    DECIMAL(18, 2),
    PIS_BASE_TOTAL                  DECIMAL(18, 2),
    PIS_BASE_APROVADA               DECIMAL(18, 2),
    PIS_BASE_REPROVADA              DECIMAL(18, 2),
    COFINS_VALOR_TOTAL              DECIMAL(18, 2),
    COFINS_VALOR_APROVADA           DECIMAL(18, 2),
    COFINS_VALOR_REPROVADA          DECIMAL(18, 2),
    COFINS_ALIQUOTA                 DECIMAL(18, 2),
    COFINS_BASE_TOTAL               DECIMAL(18, 2),
    COFINS_BASE_APROVADA            DECIMAL(18, 2),
    COFINS_BASE_REPROVADA           DECIMAL(18, 2),
    IPI_VALOR_TOTAL                 DECIMAL(18, 2),
    IPI_VALOR_APROVADA              DECIMAL(18, 2),
    IPI_VALOR_REPROVADA             DECIMAL(18, 2),
    IPI_ALIQUOTA                    DECIMAL(18, 2),
    IPI_BASE_TOTAL                  DECIMAL(18, 2),
    IPI_BASE_APROVADA               DECIMAL(18, 2),
    IPI_BASE_REPROVADA              DECIMAL(18, 2),
    ST_VALOR_TOTAL                  DECIMAL(18, 2),
    ST_VALOR_APROVADA               DECIMAL(18, 2),
    ST_VALOR_REPROVADA              DECIMAL(18, 2),
    ST_BASE_TOTAL                   DECIMAL(18, 2),
    ST_BASE_APROVADA                DECIMAL(18, 2),
    ST_BASE_REPROVADA               DECIMAL(18, 2),
    SUFRAMA_VALOR_TOTAL             DECIMAL(18, 2),
    SUFRAMA_VALOR_APROVADA          DECIMAL(18, 2),
    SUFRAMA_VALOR_REPROVADA         DECIMAL(18, 2),
    SEGURO_VALOR_TOTAL              DECIMAL(18, 2),
    SEGURO_VALOR_APROVADA           DECIMAL(18, 2),
    SEGURO_VALOR_REPROVADA          DECIMAL(18, 2),
    DESCONTO_VALOR_TOTAL            DECIMAL(18, 2),
    DESCONTO_VALOR_APROVADA         DECIMAL(18, 2),
    DESCONTO_VALOR_REPROVADA        DECIMAL(18, 2),
    OUTRAS_DESPESAS_VALOR_TOTAL     DECIMAL(18, 2),
    OUTRAS_DESPESAS_VALOR_APROVADA  DECIMAL(18, 2),
    OUTRAS_DESPESAS_VALOR_REPROVADA DECIMAL(18, 2),
    VALOR_FRETE_TOTAL               DECIMAL(18, 2),
    VALOR_FRETE_APROVADA            DECIMAL(18, 2),
    VALOR_FRETE_REPROVADA           DECIMAL(18, 2),
    VALOR_BRUTO_TOTAL               DECIMAL(18, 2),
    VALOR_BRUTO_APROVADA            DECIMAL(18, 2),
    VALOR_BRUTO_REPROVADA           DECIMAL(18, 2),
    CADASTRADO_POR                  VARCHAR(60),
    DATA_CADASTRO                   DATETIME NOT NULL,
    ULTIMA_MODIFICACAO_POR          VARCHAR(60),
    DATA_ULTIMA_ALTERACAO           DATETIME,
    DELETADO                        BIT,
    ID_LAUDO_ITEM                   INT NOT NULL CONSTRAINT FK_LAUDO_SUB_ITEM_ON_LAUDO_ITEM FOREIGN KEY REFERENCES LAUDO_ITEM (ID),
);



-- ==================================================
--	CRIA A TABELA DE LAUDO_SUB_ITEM_DEFEITO
-- ==================================================
CREATE TABLE LAUDO_SUB_ITEM_DEFEITO
(
    ID_LAUDO_SUB_ITEM      INT      NOT NULL,
    ID_LAUDO_DEFEITO       INT      NOT NULL,
    QUANTIDADE             INT,
    CADASTRADO_POR         VARCHAR(60),
    DATA_CADASTRO          DATETIME NOT NULL,
    ULTIMA_MODIFICACAO_POR VARCHAR(60),
    DATA_ULTIMA_ALTERACAO  DATETIME,
    DELETADO               BIT,
    CONSTRAINT PK_LAUDO_SUB_ITEM_DEFEITO PRIMARY KEY (ID_LAUDO_SUB_ITEM, ID_LAUDO_DEFEITO),
    CONSTRAINT FK_LAUDO_SUB_ITEM_DEFEITO_ON_LAUDO_SUB_ITEM FOREIGN KEY (ID_LAUDO_SUB_ITEM) REFERENCES LAUDO_SUB_ITEM (ID),
    CONSTRAINT FK_LAUDO_SUB_ITEM_DEFEITO_ON_LAUDO_DEFEITO FOREIGN KEY (ID_LAUDO_DEFEITO) REFERENCES LAUDO_DEFEITO (ID)
);

-- ==================================================
--	CRIAR VINCULO COM O LAUDO NA SOLICITACAO
-- ==================================================
ALTER TABLE SOLICITACAO ADD
    ID_LAUDO INT CONSTRAINT FK_SOLICITACAO_T_LAUDO FOREIGN KEY REFERENCES LAUDO(ID);