-- ==================================================
--	CRIA A TABELA CONTA
-- ==================================================
CREATE TABLE CONTA
(
    ID                     INT IDENTITY (1, 1) NOT NULL,
    TIPO                   VARCHAR(40)         NOT NULL,
    SALDO                  DECIMAL(18, 2)      NOT NULL,
    DELETADO               BIT,
    CADASTRADO_POR         VARCHAR(60),
    DATA_CADASTRO          DATETIME            NOT NULL,
    ULTIMA_MODIFICACAO_POR VARCHAR(60),
    DATA_ULTIMA_ALTERACAO  DATETIME,
    ID_USUARIO             INT,
    ID_REGIONAL            INT,
    CONSTRAINT PK_CONTA PRIMARY KEY (ID)
)
GO

ALTER TABLE CONTA
    ADD CONSTRAINT UC_CONTA_TIPO_USUARIO_REGIONAL UNIQUE (TIPO, ID_USUARIO, ID_REGIONAL)
GO

ALTER TABLE CONTA
    ADD CONSTRAINT FK_CONTA_ON_REGIONAL FOREIGN KEY (ID_REGIONAL) REFERENCES REGIONAL (ID)
GO

ALTER TABLE CONTA
    ADD CONSTRAINT FK_CONTA_ON_USUARIO FOREIGN KEY (ID_USUARIO) REFERENCES USUARIO (ID)
GO

-- ==================================================
--	CRIA A TABELA CONTA_TRANSACAO
-- ==================================================
CREATE TABLE CONTA_TRANSACAO
(
    ID                     BINARY(16)                             NOT NULL,
    AUTORIZACAO            UNIQUEIDENTIFIER
        CONSTRAINT DF_CONTA_TRANSACAO_AUTORIZACAO DEFAULT NEWID() NOT NULL,
    SEQUENCIAL             BIGINT                                 NOT NULL,
    TIPO                   VARCHAR(8)                             NOT NULL,
    CODIGO                 VARCHAR(3)                             NOT NULL,
    DESCRICAO              VARCHAR(255)                           NOT NULL,
    OBSERVACAO             VARCHAR(510),
    VALOR                  DECIMAL(18, 2)                         NOT NULL,
    CADASTRADO_POR         VARCHAR(60),
    DATA_CADASTRO          DATETIME                               NOT NULL,
    ULTIMA_MODIFICACAO_POR VARCHAR(60),
    DATA_ULTIMA_ALTERACAO  DATETIME,
    ID_CONTA               INT                                    NOT NULL,
    CONSTRAINT PK_CONTA_TRANSACAO PRIMARY KEY (ID)
)
GO


ALTER TABLE CONTA_TRANSACAO
    ADD CONSTRAINT FK_CONTA_TRANSACAO_ON_CONTA FOREIGN KEY (ID_CONTA) REFERENCES CONTA (ID)
GO

ALTER TABLE CONTA_TRANSACAO
    ADD CONSTRAINT UC_CONTA_TRANSACAO_AUTORIZACAO UNIQUE (AUTORIZACAO)
GO

ALTER TABLE CONTA_TRANSACAO
    ADD CONSTRAINT UC_CONTA_TRANSACAO_SEQUENCIAL_TIPO UNIQUE (SEQUENCIAL, TIPO)
GO


CREATE NONCLUSTERED INDEX IX_CONTA_TRANSACAO_SEQUENCIAL_ASC
    ON CONTA_TRANSACAO (SEQUENCIAL ASC)
GO

CREATE NONCLUSTERED INDEX IX_CONTA_TRANSACAO_SEQUENCIAL_DESC
    ON CONTA_TRANSACAO (SEQUENCIAL DESC)
GO

CREATE UNIQUE INDEX IX_UNIQUE_CODIGO_OBS_VALOR
    ON CONTA_TRANSACAO (CODIGO, OBSERVACAO, VALOR)
    WHERE CODIGO IN ('004', '005', '006', '504', '505', '506')
GO

