-- ==================================================
--	CRIA A TABELA VOUCHER
-- ==================================================
CREATE TABLE VOUCHER
(
    ID                     INT IDENTITY (1, 1) NOT NULL,
    CODIGO                 VARCHAR(12)         NOT NULL,
    TIPO                   VARCHAR(20)         NOT NULL,
    STATUS                 VARCHAR(20)         NOT NULL,
    VALOR                  DECIMAL(18, 2)      NOT NULL,
    OBSERVACAO             VARCHAR(510),
    NUMERO_CONTRATO        VARCHAR(9),
    TIPO_PREMIO            VARCHAR(4),
    DATA_VENCIMENTO        DATE,
    DELETADO               BIT,
    CADASTRADO_POR         VARCHAR(60),
    DATA_CADASTRO          DATETIME            NOT NULL,
    ULTIMA_MODIFICACAO_POR VARCHAR(60),
    DATA_ULTIMA_ALTERACAO  DATETIME,
    ID_ZZ8010              INT,
    ID_CLIENTE             INT,
    ID_CLIENTE_GRUPO       INT,
    ID_REGIONAL            INT,
    ID_REPRESENTANTE       INT,
    ID_ORCAMENTO           INT,
    ID_PRE_NOTA            INT,
    CONSTRAINT PK_VOUCHER PRIMARY KEY (ID)
)
GO

ALTER TABLE VOUCHER
    ADD CONSTRAINT UC_VOUCHER_CODIGO UNIQUE (CODIGO)
GO

ALTER TABLE VOUCHER
    ADD CONSTRAINT FK_VOUCHER_ON_ID_CLIENTE FOREIGN KEY (ID_CLIENTE) REFERENCES CLIENTE (ID)
GO

ALTER TABLE VOUCHER
    ADD CONSTRAINT FK_VOUCHER_ON_ID_CLIENTE_GRUPO FOREIGN KEY (ID_CLIENTE_GRUPO) REFERENCES CLIENTE_GRUPO (ID)
GO

ALTER TABLE VOUCHER
    ADD CONSTRAINT FK_VOUCHER_ON_ID_ORCAMENTO FOREIGN KEY (ID_ORCAMENTO) REFERENCES ORCAMENTO (ID)
GO

ALTER TABLE VOUCHER
    ADD CONSTRAINT FK_VOUCHER_ON_ID_PRE_NOTA FOREIGN KEY (ID_PRE_NOTA) REFERENCES PRE_NOTA (ID)
GO

ALTER TABLE VOUCHER
    ADD CONSTRAINT FK_VOUCHER_ON_ID_REGIONAL FOREIGN KEY (ID_REGIONAL) REFERENCES REGIONAL (ID)
GO

ALTER TABLE VOUCHER
    ADD CONSTRAINT FK_VOUCHER_ON_ID_REPRESENTANTE FOREIGN KEY (ID_REPRESENTANTE) REFERENCES REPRESENTANTE (ID_USUARIO)
GO

-- ==================================================
--	ALTERA A TABELA DE VOUCHER CRIANDO UM UNIQUE QUE IGNORA VALORES NULL
-- ==================================================
CREATE UNIQUE NONCLUSTERED INDEX UC_VOUCHER_ID_ZZ8010
    ON VOUCHER(ID_ZZ8010)
    WHERE ID_ZZ8010 IS NOT NULL
GO

-- ==================================================
--	ALTERA A TABELA DE VOUCHER CRIANDO UMA VALIDAÇÃO QUE IMPEDE VALORES ZERADOS OU NEGATIVOS
-- ==================================================
ALTER TABLE VOUCHER
    ADD CONSTRAINT CK_VOUCHER_VALOR_POSITIVO CHECK (VALOR > 0)
GO


-- ==================================================
--	ALTERAR A TABELA SOLICITACAO
-- ==================================================
ALTER TABLE SOLICITACAO ADD
    ID_VOUCHER             INT
GO

ALTER TABLE SOLICITACAO
    ADD CONSTRAINT FK_SOLICITACAO_ON_ID_VOUCHER FOREIGN KEY (ID_VOUCHER) REFERENCES VOUCHER (ID)
GO

-- ==================================================
--	ALTERAR A TABELA ORCAMENTO
-- ==================================================
ALTER TABLE ORCAMENTO ADD
    VALOR_TOTAL_VOUCHER        DECIMAL(18, 2),
    VALOR_MAXIMO_VOUCHER       DECIMAL(19, 2),
    VALOR_TOTAL_ORIGINAL       DECIMAL(18, 2)
GO


-- ==================================================
--	ALTERAR A TABELA ORCAMENTO_ITEM
-- ==================================================
ALTER TABLE ORCAMENTO_ITEM ADD
    COEFICIENTE                            DECIMAL(19, 8),
    VALOR_RATEIO_VOUCHER                   DECIMAL(19, 2),
    VALOR_TOTAL_VOUCHER                    DECIMAL(19, 2),

    PRECO_VENDA_ORIGINAL                   DECIMAL(18, 2),
    VALOR_TOTAL_ORIGINAL                   DECIMAL(18, 2)
GO

