ALTER TABLE RESERVA
    ADD
        STATUS                      VARCHAR(20),
        QUEUE_ORIGIN_STATUS         VARCHAR(15),
        QUEUE_ORIGIN_TRIES          INT,
        QUEUE_ORIGIN_ERROR_LOG      VARBINARY(MAX),
        QUANTIDADE_SALDO_DIVISAO    INT,
        QUANTIDADE_JUNCAO           INT,
        ID_RESERVA_PAI_DIVISAO      INT,
        ID_RESERVA_PAI_JUNCAO       INT,
        DELETED                     BIT
GO

ALTER TABLE RESERVA
    ADD CONSTRAINT FK_RESERVA_ON_ID_RESERVA_PAI_JUNCAO FOREIGN KEY (ID_RESERVA_PAI_JUNCAO) REFERENCES RESERVA (ID)
GO

ALTER TABLE RESERVA
    ADD CONSTRAINT FK_RESERVA_ON_ID_RESERVA_PAI_DIVISAO FOREIGN KEY (ID_RESERVA_PAI_DIVISAO) REFERENCES RESERVA (ID)
GO

-- REMOÇÃO DE VALORES NULL DE DELETADO
UPDATE RESERVA SET DELETED = COALESCE(DELETADO, 0)
FROM RESERVA
WHERE DELETED IS NULL
GO

ALTER TABLE RESERVA
    ALTER COLUMN DELETED    BIT     NOT NULL
GO

ALTER TABLE RESERVA
    ADD CONSTRAINT DF_RESERVA_DELETED DEFAULT 0 FOR DELETED
GO

-- Índice não clusterizado na coluna DELETED
CREATE NONCLUSTERED INDEX IX_RESERVA_DELETED
    ON RESERVA (DELETED);
GO

DROP INDEX IX_RESERVA_STATUS_APROVACAO ON RESERVA
GO

ALTER TABLE RESERVA
    DROP COLUMN DELETADO
GO

-- REMOÇÃO DE VALORES NULL DE CODIGO_SC0010
UPDATE RESERVA SET CODIGO_SC0010 = ''
FROM RESERVA
WHERE CODIGO_SC0010 IS NULL

ALTER TABLE RESERVA
    ALTER COLUMN CODIGO_SC0010    VARCHAR(6)	NOT NULL
GO

ALTER TABLE RESERVA
    ADD CONSTRAINT DF_RESERVA_CODIGO_SC0010 DEFAULT '' FOR CODIGO_SC0010
GO


-- REMOÇÃO DE VALORES NULL DE SYNC_TOTVS
UPDATE RESERVA SET SYNC_TOTVS = 0
FROM RESERVA
WHERE SYNC_TOTVS IS NULL

ALTER TABLE RESERVA
    ALTER COLUMN SYNC_TOTVS    BIT	NOT NULL
GO

ALTER TABLE RESERVA
    ADD CONSTRAINT DF_RESERVA_SYNC_TOTVS DEFAULT 0 FOR SYNC_TOTVS
GO

-- REMOÇÃO DE VALORES NULL DE USADA_TOTVS
UPDATE RESERVA SET USADA_TOTVS = 0
FROM RESERVA
WHERE USADA_TOTVS IS NULL

ALTER TABLE RESERVA
    ALTER COLUMN USADA_TOTVS    BIT	NOT NULL
GO

ALTER TABLE RESERVA
    ADD CONSTRAINT DF_RESERVA_USADA_TOTVS DEFAULT 0 FOR USADA_TOTVS
GO


-- REMOÇÃO DE VALORES NULL DE ESTOQUE_EMPENHADO
UPDATE RESERVA SET ESTOQUE_EMPENHADO = 0
FROM RESERVA
WHERE ESTOQUE_EMPENHADO IS NULL

ALTER TABLE RESERVA
    ALTER COLUMN ESTOQUE_EMPENHADO    BIT	NOT NULL
GO

ALTER TABLE RESERVA
    ADD CONSTRAINT DF_RESERVA_ESTOQUE_EMPENHADO DEFAULT 0 FOR ESTOQUE_EMPENHADO
GO


-- REMOÇÃO DE VALORES NULL DE USADA
UPDATE RESERVA SET USADA = 0
FROM RESERVA
WHERE USADA IS NULL

ALTER TABLE RESERVA
    ALTER COLUMN USADA    BIT	NOT NULL
GO

ALTER TABLE RESERVA
    ADD CONSTRAINT DF_RESERVA_USADA DEFAULT 0 FOR USADA
GO


-- REMOÇÃO DE VALORES NULL DE OBSERVACAO
UPDATE RESERVA SET OBSERVACAO = ''
FROM RESERVA
WHERE OBSERVACAO IS NULL

ALTER TABLE RESERVA
    ALTER COLUMN OBSERVACAO    VARCHAR(80)	NOT NULL
GO

ALTER TABLE RESERVA
    ADD CONSTRAINT DF_RESERVA_OBSERVACAO DEFAULT '' FOR OBSERVACAO
GO


-- REMOÇÃO DE VALORES NULL DE RESERVA
UPDATE RESERVA SET DATA_VALIDADE = '1900-01-01'
FROM RESERVA
WHERE DATA_VALIDADE IS NULL

ALTER TABLE RESERVA
    ALTER COLUMN DATA_VALIDADE    DATE	NOT NULL
GO

ALTER TABLE RESERVA
    ADD CONSTRAINT DF_RESERVA_DATA_VALIDADE DEFAULT '1900-01-01' FOR DATA_VALIDADE
GO

ALTER TABLE RESERVA
    ALTER COLUMN DATA_CADASTRO    DATETIME	NOT NULL
GO

ALTER TABLE RESERVA
    ADD CONSTRAINT DF_RESERVA_DATA_CADASTRO DEFAULT GETDATE() FOR DATA_CADASTRO
GO


ALTER TABLE RESERVA
    ALTER COLUMN DATA_ULTIMA_ALTERACAO    DATETIME	NOT NULL
GO

ALTER TABLE RESERVA
    ADD CONSTRAINT DF_RESERVA_DATA_ULTIMA_ALTERACAO DEFAULT GETDATE() FOR DATA_ULTIMA_ALTERACAO
GO



ALTER TABLE RESERVA
    ALTER COLUMN CADASTRADO_POR    VARCHAR(60)	NOT NULL
GO

ALTER TABLE RESERVA
    ADD CONSTRAINT DF_RESERVA_CADASTRADO_POR DEFAULT '' FOR CADASTRADO_POR
GO

ALTER TABLE RESERVA
    ALTER COLUMN ULTIMA_MODIFICACAO_POR    VARCHAR(60)	NOT NULL
GO

ALTER TABLE RESERVA
    ADD CONSTRAINT DF_RESERVA_ULTIMA_MODIFICACAO_POR DEFAULT '' FOR ULTIMA_MODIFICACAO_POR
GO





UPDATE RESERVA SET STATUS_APROVACAO = 'EMPTY'
FROM RESERVA
WHERE STATUS_APROVACAO IS NULL


ALTER TABLE RESERVA
    ALTER COLUMN STATUS_APROVACAO  VARCHAR(20)	NOT NULL
GO

ALTER TABLE RESERVA
    ADD CONSTRAINT DF_RESERVA_STATUS_APROVACAO DEFAULT 'EMPTY' FOR STATUS_APROVACAO
GO


-- REMOÇÃO DE VALORES NULL DE RESERVA
UPDATE RESERVA SET ID_SC0010 = 0
FROM RESERVA
WHERE ID_SC0010 IS NULL

ALTER TABLE RESERVA
    ALTER COLUMN ID_SC0010 INT  NOT NULL
GO

ALTER TABLE RESERVA
    ADD CONSTRAINT DF_RESERVA_ID_SC0010 DEFAULT 0 FOR ID_SC0010
GO


ALTER TABLE RESERVA
    ADD CONSTRAINT DF_RESERVA_FILIAL DEFAULT 'SANTA_CATARINA' FOR FILIAL
GO

ALTER TABLE RESERVA
    ADD
        CONSTRAINT CK_RESERVA_FILIAL
            CHECK ([FILIAL] IN
                   ('SANTA_CATARINA', 'SAO_FRANCISCO', 'PINHAIS', 'MATRIZ'))
GO


-- REMOÇÃO DE VALORES NULL DE QUEUE_ORIGIN_STATUS
UPDATE RESERVA SET QUEUE_ORIGIN_STATUS = 'PENDING'
FROM RESERVA
WHERE QUEUE_ORIGIN_STATUS IS NULL
GO

ALTER TABLE RESERVA
    ALTER COLUMN QUEUE_ORIGIN_STATUS    VARCHAR(15)	NOT NULL
GO

ALTER TABLE RESERVA
    ADD CONSTRAINT DF_RESERVA_QUEUE_ORIGIN_STATUS DEFAULT 'PENDING' FOR QUEUE_ORIGIN_STATUS
GO

ALTER TABLE RESERVA
    ADD
        CONSTRAINT CK_RESERVA_QUEUE_ORIGIN_STATUS
            CHECK ([QUEUE_ORIGIN_STATUS] IN
                   ('PENDING', 'VALIDATED', 'RETRY', 'ERROR', 'SENT_TO_QUEUE', 'SUCCESS'))
GO

-- REMOÇÃO DE VALORES NULL DE QUEUE_ORIGIN_ERROR_LOG
UPDATE RESERVA SET QUEUE_ORIGIN_ERROR_LOG = 0x
FROM RESERVA
WHERE QUEUE_ORIGIN_ERROR_LOG IS NULL
GO

ALTER TABLE RESERVA
    ALTER COLUMN QUEUE_ORIGIN_ERROR_LOG	VARBINARY(MAX) NOT NULL
GO

ALTER TABLE RESERVA
    ADD CONSTRAINT DF_RESERVA_QUEUE_ORIGIN_ERROR_LOG DEFAULT 0x FOR QUEUE_ORIGIN_ERROR_LOG
GO

-- REMOÇÃO DE VALORES NULL DE QUANTIDADE_SALDO_DIVISAO
UPDATE RESERVA SET QUANTIDADE_SALDO_DIVISAO = 0
FROM RESERVA
WHERE QUANTIDADE_SALDO_DIVISAO IS NULL
GO

ALTER TABLE RESERVA
    ALTER COLUMN QUANTIDADE_SALDO_DIVISAO  INT	NOT NULL
GO


ALTER TABLE RESERVA
    ADD CONSTRAINT DF_RESERVA_QUANTIDADE_SALDO_DIVISAO DEFAULT 0 FOR QUANTIDADE_SALDO_DIVISAO
GO


ALTER TABLE RESERVA
    ADD  CONSTRAINT CK_RESERVA_QUANTIDADE_SALDO_DIVISAO_POSITIVA CHECK  (QUANTIDADE_SALDO_DIVISAO > -1)
GO



-- REMOÇÃO DE VALORES NULL DE QUANTIDADE_ORIGINAL
UPDATE RESERVA SET QUANTIDADE_ORIGINAL = 0
FROM RESERVA
WHERE QUANTIDADE_ORIGINAL IS NULL
GO

ALTER TABLE RESERVA
    ALTER COLUMN QUANTIDADE_ORIGINAL  INT	NOT NULL
GO


ALTER TABLE RESERVA
    ADD CONSTRAINT DF_RESERVA_QUANTIDADE_ORIGINAL DEFAULT 0 FOR QUANTIDADE_ORIGINAL
GO


ALTER TABLE RESERVA
    ADD  CONSTRAINT CK_RESERVA_QUANTIDADE_ORIGINAL_POSITIVA CHECK  (QUANTIDADE_ORIGINAL > -1)
GO


-- REMOÇÃO DE VALORES NULL DE QUANTIDADE_SALDO
        UPDATE RESERVA SET QUANTIDADE_SALDO = 0
        FROM RESERVA
        WHERE QUANTIDADE_ORIGINAL IS NULL
GO

ALTER TABLE RESERVA
    ALTER COLUMN QUANTIDADE_SALDO  INT	NOT NULL
GO


ALTER TABLE RESERVA
    ADD CONSTRAINT DF_RESERVA_QUANTIDADE_SALDO DEFAULT 0 FOR QUANTIDADE_SALDO
GO


ALTER TABLE RESERVA
    ADD  CONSTRAINT CK_RESERVA_QUANTIDADE_SALDO_POSITIVA CHECK  (QUANTIDADE_SALDO > -1)
GO


UPDATE RESERVA SET QUEUE_ORIGIN_TRIES = 0
FROM RESERVA
WHERE QUEUE_ORIGIN_TRIES IS NULL
GO


ALTER TABLE RESERVA
    ALTER COLUMN QUEUE_ORIGIN_TRIES    INT     NOT NULL
GO


ALTER TABLE RESERVA
    ADD CONSTRAINT DF_RESERVA_QUEUE_ORIGIN_TRIES DEFAULT 0 FOR QUEUE_ORIGIN_TRIES
GO


-- REMOÇÃO DE VALORES NULL DE QUANTIDADE_ELIMINADA
UPDATE RESERVA SET QUANTIDADE_ELIMINADA = 0
FROM RESERVA
WHERE QUANTIDADE_ELIMINADA IS NULL
GO

ALTER TABLE RESERVA
    ALTER COLUMN QUANTIDADE_ELIMINADA  INT	NOT NULL
GO


ALTER TABLE RESERVA
    ADD CONSTRAINT DF_RESERVA_QUANTIDADE_ELIMINADA DEFAULT 0 FOR QUANTIDADE_ELIMINADA
GO


ALTER TABLE RESERVA
    ADD  CONSTRAINT CK_RESERVA_QUANTIDADE_ELIMINADA_POSITIVA CHECK  (QUANTIDADE_ELIMINADA > -1)
GO


-- REMOÇÃO DE VALORES NULL DE QUANTIDADE_JUNCAO
UPDATE RESERVA SET QUANTIDADE_JUNCAO = 0
FROM RESERVA
WHERE QUANTIDADE_JUNCAO IS NULL
GO

ALTER TABLE RESERVA
    ALTER COLUMN QUANTIDADE_JUNCAO  INT	NOT NULL
GO

ALTER TABLE RESERVA
    ADD CONSTRAINT DF_RESERVA_QUANTIDADE_JUNCAO DEFAULT 0 FOR QUANTIDADE_JUNCAO
GO

ALTER TABLE RESERVA
    ADD  CONSTRAINT CK_RESERVA_QUANTIDADE_JUNCAO_POSITIVA CHECK  (QUANTIDADE_JUNCAO > -1)
GO



-- REMOÇÃO DE VALORES NULL DE STATUS EDICAO
UPDATE RESERVA SET STATUS = 'EDICAO'
FROM RESERVA
WHERE STATUS IS NULL
GO


-- MARCANDO STATUS COMO NOT NULL
ALTER TABLE RESERVA
    ALTER COLUMN STATUS  VARCHAR(20)	NOT NULL
GO


-- APLICANDO STATUS DELETADO
UPDATE RESERVA SET STATUS = 'DELETADO'
FROM RESERVA
WHERE COALESCE(DELETED, 0) = 1
GO


-- APLICANDO STATUS ANALISE
UPDATE RESERVA SET STATUS = 'ANALISE'
FROM RESERVA
WHERE COALESCE(STATUS_APROVACAO, '') = 'ANALISE'
  AND STATUS = 'EDICAO'
GO


-- APLICANDO STATUS REPROVADA
UPDATE RESERVA SET STATUS = 'REPROVADO'
FROM RESERVA
WHERE COALESCE(STATUS_APROVACAO, '') = 'REPROVADA'
  AND STATUS = 'EDICAO'
GO


-- APLICANDO STATUS APROVADO
UPDATE RESERVA SET STATUS = 'APROVADO'
FROM RESERVA
WHERE COALESCE(STATUS_APROVACAO, '') = 'SINCRONISMO'
  AND STATUS = 'EDICAO'
GO

-- APLICANDO STATUS APROVADO
UPDATE RESERVA SET STATUS = 'SEM_SALDO'
FROM RESERVA
WHERE COALESCE(STATUS_APROVACAO, '') = 'SEM_SALDO'
  AND STATUS = 'EDICAO'
GO

-- APLICANDO STATUS CANCELADO
UPDATE RESERVA SET STATUS = 'CANCELADO'
FROM RESERVA
WHERE COALESCE(STATUS_APROVACAO, '') = 'DELETADO'
  AND STATUS = 'EDICAO'
GO

-- APLICANDO STATUS RETORNADO
UPDATE RESERVA SET STATUS = 'RETORNADO'
FROM RESERVA
WHERE COALESCE(STATUS_APROVACAO, '') = 'ERRO_INTEGRACAO'
  AND STATUS = 'EDICAO'
GO

-- APLICANDO STATUS USADO
UPDATE RESERVA SET STATUS = 'USADO'
FROM RESERVA
WHERE COALESCE(DELETED, 0) = 0
  AND STATUS = 'EDICAO'
  AND COALESCE(USADA, 0) = 1
GO

UPDATE RESERVA SET STATUS = 'USADO'
FROM RESERVA
         INNER JOIN ORCAMENTO_ITEM ON RESERVA.ID = ORCAMENTO_ITEM.ID_RESERVA AND COALESCE(ORCAMENTO_ITEM.DELETADO, 0) = 0
WHERE COALESCE(RESERVA.DELETED, 0) = 0
  AND RESERVA.STATUS = 'EDICAO'
GO

UPDATE RESERVA SET STATUS = 'USADO'
FROM RESERVA
         INNER JOIN PEDIDO_ITEM ON RESERVA.ID = PEDIDO_ITEM.ID_RESERVA AND COALESCE(PEDIDO_ITEM.DELETADO, 0) = 0
WHERE COALESCE(RESERVA.DELETED, 0) = 0
  AND RESERVA.STATUS = 'EDICAO'
GO

-- APLICANDO STATUS PRONTO_PARA_USO
UPDATE RESERVA SET STATUS = 'PRONTO_PARA_USO'
FROM RESERVA
WHERE COALESCE(DELETED, 0) = 0
  AND STATUS = 'EDICAO'
  AND COALESCE(USADA, 0) = 0
  AND COALESCE(CODIGO_SC0010, '') <> ''
GO



ALTER TABLE RESERVA
    ADD CONSTRAINT DF_RESERVA_STATUS DEFAULT 'EDICAO' FOR [STATUS]
GO


ALTER TABLE RESERVA
    ADD CONSTRAINT CK_RESERVA_STATUS
        CHECK ([STATUS]
            IN (
                'EDICAO',
                'ANALISE',
                'REPROVADO',
                'APROVADO',
                'SEM_SALDO',
                'PRONTO_PARA_USO',
                'USADO',
                'DELETADO',
                'CANCELADO',
                'RETORNADO',
                'ESTORNADO',
                'EM_DIVISAO',
                'AJUSTE_DIVISAO',
                'DIVIDIDO',
                'EM_JUNCAO',
                'AJUSTE_JUNCAO',
                'JUNTADO',
                'QUEUE_DIVIDIDO',
                'QUEUE_JUNCAO'
                   ))
GO



ALTER TABLE RESERVA
    ADD CONSTRAINT CK_RESERVA_STATUS_APROVACAO
        CHECK ([STATUS_APROVACAO]
            IN (
                'EMPTY',
                'NOVO',
                'ANALISE',
                'AGUARDANDO_APROVACAO',
                'SINCRONISMO',
                'INTEGRADO',
                'GERADO_PARCIAL',
                'GERADO_TOTAL',
                'REPROVADA',
                'SEM_SALDO',
                'ERRO_INTEGRACAO',
                'DELETADO'
                   ))
GO



