CREATE TABLE QUEUE
(
    ID          BINARY(16)     NOT NULL,
    CREATED_AT  DATETIME       NOT NULL,
    UPDATED_AT  DATETIME       NOT NULL,
    STATUS      VARCHAR(10)    NOT NULL,
    PROCESS     VARCHAR(50)    NOT NULL,
    DESCRIPTION VARCHAR(255)   NOT NULL,
    TRIES       INT            NOT NULL,
    DATA_FORMAT VARCHAR(50)    NOT NULL,
    DATA        VARBINARY(MAX) NOT NULL,
    DELETED     BIT            NOT NULL,
    ID_RESERVA  INT,
    CONSTRAINT PK_QUEUE PRIMARY KEY (ID)
)
GO

ALTER TABLE QUEUE
    ADD CONSTRAINT FK_QUEUE_ON_ID_RESERVA FOREIGN KEY (ID_RESERVA) REFERENCES RESERVA (ID)
GO

ALTER TABLE QUEUE
    ADD  CONSTRAINT DF_QUEUE_ID DEFAULT CONVERT(BINARY(16), NEWID()) FOR ID
GO

ALTER TABLE QUEUE
    ADD CONSTRAINT DF_QUEUE_CREATED_AT DEFAULT GETDATE() FOR CREATED_AT
GO

ALTER TABLE QUEUE
    ADD CONSTRAINT DF_QUEUE_UPDATED_AT DEFAULT GETDATE() FOR UPDATED_AT
GO

ALTER TABLE QUEUE
    ADD CONSTRAINT DF_QUEUE_STATUS DEFAULT 'QUEUED' FOR STATUS
GO

ALTER TABLE QUEUE
    ADD CONSTRAINT DF_QUEUE_DESCRIPTION DEFAULT '' FOR DESCRIPTION
GO

ALTER TABLE QUEUE
    ADD CONSTRAINT DF_QUEUE_TRIES DEFAULT 0 FOR TRIES
GO

ALTER TABLE QUEUE
    ADD CONSTRAINT DF_QUEUE_DATA_FORMAT DEFAULT '' FOR DATA_FORMAT
GO

ALTER TABLE QUEUE
    ADD CONSTRAINT DF_QUEUE_DELETED DEFAULT 0 FOR DELETED
GO


ALTER TABLE QUEUE
    ADD
        CONSTRAINT CK_QUEUE_STATUS
            CHECK ([STATUS] IN
                   ('QUEUED', 'SENDING', 'SENT', 'FAILED', 'RETRY', 'COMPLETED', 'CANCELLED'))
GO


ALTER TABLE QUEUE
    ADD
        CONSTRAINT CK_QUEUE_PROCESS
            CHECK ([PROCESS] IN
                   ('RESERVA_DIVISAO', 'RESERVA_JUNCAO'))
GO


-- Índice combinado nas colunas STATUS, PROCESS e DELETED
CREATE NONCLUSTERED INDEX IX_QUEUE_STATUS_PROCESS_DELETED
    ON QUEUE (STATUS, PROCESS, DELETED);
GO

-- Índice não clusterizado nas colunas STATUS e DELETED
CREATE NONCLUSTERED INDEX IX_QUEUE_STATUS_DELETED
    ON QUEUE (STATUS, DELETED);
GO

-- Índice não clusterizado nas colunas PROCESS e DELETED
CREATE NONCLUSTERED INDEX IX_QUEUE_PROCESS_DELETED
    ON QUEUE (PROCESS, DELETED);
GO

-- Índice não clusterizado na coluna DELETED
CREATE NONCLUSTERED INDEX IX_QUEUE_DELETED
    ON QUEUE (DELETED);
GO


