CREATE TABLE TAG
(
    ID                     INT IDENTITY (1, 1) NOT NULL,
    CADASTRADO_POR         VARCHAR(60)         NOT NULL,
    DATA_CADASTRO          DATETIME            NOT NULL,
    ULTIMA_MODIFICACAO_POR VARCHAR(60)         NOT NULL,
    DATA_ULTIMA_ALTERACAO  DATETIME            NOT NULL,
    NAME                   VARCHAR(255)        NOT NULL,
    DESCRIPTION            VARCHAR(500)        NOT NULL,
    SEVERITY               VARCHAR(10)         NOT NULL,
    ICON                   VARCHAR(100)        NOT NULL,
    SYSTEM_GENERATED       BIT                 NOT NULL,
    DELETED                BIT                 NOT NULL,
    ID_CATEGORY            INT                 NOT NULL,
    ID_USUARIO             INT,
    CONSTRAINT PK_TAG PRIMARY KEY (ID)
)
GO

ALTER TABLE TAG
    ADD CONSTRAINT UC_TAG_NAME UNIQUE (NAME)
GO

ALTER TABLE TAG
    ADD CONSTRAINT FK_TAG_ON_CATEGORY FOREIGN KEY (ID_CATEGORY) REFERENCES TAG_CATEGORY (ID)
GO

ALTER TABLE TAG
    ADD CONSTRAINT FK_TAG_ON_USUARIO FOREIGN KEY (ID_USUARIO) REFERENCES USUARIO (ID)
GO

ALTER TABLE TAG
    ADD CONSTRAINT DF_TAG_CADASTRADO_POR DEFAULT '' FOR CADASTRADO_POR
GO

ALTER TABLE TAG
    ADD CONSTRAINT DF_TAG_ULTIMA_DATA_CADASTRO DEFAULT GETDATE() FOR DATA_CADASTRO
GO

ALTER TABLE TAG
    ADD CONSTRAINT DF_TAG_ULTIMA_MODIFICACAO_POR DEFAULT '' FOR ULTIMA_MODIFICACAO_POR
GO

ALTER TABLE TAG
    ADD CONSTRAINT DF_TAG_DATA_ULTIMA_ALTERACAO DEFAULT GETDATE() FOR DATA_ULTIMA_ALTERACAO
GO

ALTER TABLE TAG
    ADD CONSTRAINT DF_TAG_NAME DEFAULT '' FOR NAME
GO

ALTER TABLE TAG
    ADD CONSTRAINT DF_TAG_DESCRIPTION DEFAULT '' FOR DESCRIPTION
GO

ALTER TABLE TAG
    ADD CONSTRAINT DF_TAG_SEVERITY DEFAULT 'INFO' FOR SEVERITY
GO

ALTER TABLE TAG
    ADD CONSTRAINT DF_TAG_ICON DEFAULT '' FOR ICON
GO

ALTER TABLE TAG
    ADD CONSTRAINT DF_TAG_SYSTEM_GENERATED DEFAULT 0 FOR SYSTEM_GENERATED
GO

ALTER TABLE TAG
    ADD CONSTRAINT DF_TAG_DELETED DEFAULT 0 FOR DELETED
GO

ALTER TABLE TAG
    ADD
        CONSTRAINT CK_TAG_SEVERITY
            CHECK ([SEVERITY] IN
                   ('INFO', 'SUCCESS', 'WARNING', 'DANGER', 'SECONDARY', 'CONTRAST'))
GO

CREATE NONCLUSTERED INDEX IX_TAG_DELETED
    ON TAG (DELETED)
GO

CREATE NONCLUSTERED INDEX IX_TAG_ID_DELETED
    ON TAG (ID, DELETED)
GO

CREATE NONCLUSTERED INDEX IX_TAG_NAME_DELETED
    ON TAG (NAME, DELETED)
GO

CREATE NONCLUSTERED INDEX IX_TAG_NAME_SYSTEM_GENERATED_DELETED
    ON TAG (NAME, SYSTEM_GENERATED, DELETED)
GO


