CREATE TABLE LEAD
(
    ID                     INT IDENTITY (1, 1) NOT NULL,
    CADASTRADO_POR         VARCHAR(60)         NOT NULL,
    DATA_CADASTRO          DATETIME            NOT NULL,
    ULTIMA_MODIFICACAO_POR VARCHAR(60)         NOT NULL,
    DATA_ULTIMA_ALTERACAO  DATETIME            NOT NULL,
    TIPO                   VARCHAR(10)         NOT NULL,
    QUALIDADE              INT                 NOT NULL,
    NOME                   VARCHAR(100)        NOT NULL,
    CNPJ                   VARCHAR(14)         NOT NULL,
    CPF                    VARCHAR(11)         NOT NULL,
    TELEFONE               VARCHAR(20)         NOT NULL,
    EMAIL                  VARCHAR(120)        NOT NULL,
    FONTE                  VARCHAR(50)         NOT NULL,
    ANOTACOES              VARCHAR(8000)       NOT NULL,
    DELETED                BIT                 NOT NULL,
    ID_ENDERECO            INT,
    ID_CONTATO             INT,
    ID_CLIENTE             INT,
    ID_REPRESENTANTE       INT,
    CONSTRAINT PK_LEAD PRIMARY KEY (ID)
)
GO

ALTER TABLE LEAD
    ADD CONSTRAINT FK_LEAD_ON_ENDERECO FOREIGN KEY (ID_ENDERECO) REFERENCES ENDERECO (ID)
GO

ALTER TABLE LEAD
    ADD CONSTRAINT FK_LEAD_ON_CONTATO FOREIGN KEY (ID_CONTATO) REFERENCES CONTATO (ID)
GO

ALTER TABLE LEAD
    ADD CONSTRAINT FK_LEAD_ON_CLIENTE FOREIGN KEY (ID_CLIENTE) REFERENCES CLIENTE (ID)
GO

ALTER TABLE LEAD
    ADD CONSTRAINT FK_LEAD_ON_REPRESENTANTE FOREIGN KEY (ID_REPRESENTANTE) REFERENCES REPRESENTANTE (ID_USUARIO)
GO

CREATE TABLE LEAD_LIG_TAG
(
    ID_LEAD INT NOT NULL,
    ID_TAG     INT NOT NULL,
    CONSTRAINT PK_LEAD_LIG_TAG PRIMARY KEY (ID_LEAD, ID_TAG)
)
GO

ALTER TABLE LEAD_LIG_TAG
    ADD CONSTRAINT FK_LEAD_LIG_TAG_ON_LEAD FOREIGN KEY (ID_LEAD) REFERENCES LEAD (ID)
GO

ALTER TABLE LEAD_LIG_TAG
    ADD CONSTRAINT FK_LEAD_LIG_TAG_ON_TAG FOREIGN KEY (ID_TAG) REFERENCES TAG (ID)
GO

ALTER TABLE LEAD
    ADD CONSTRAINT DF_LEAD_CADASTRADO_POR DEFAULT '' FOR CADASTRADO_POR
GO

ALTER TABLE LEAD
    ADD CONSTRAINT DF_LEAD_DATA_CADASTRO DEFAULT GETDATE() FOR DATA_CADASTRO
GO

ALTER TABLE LEAD
    ADD CONSTRAINT DF_LEAD_ULTIMA_MODIFICACAO_POR DEFAULT '' FOR ULTIMA_MODIFICACAO_POR
GO

ALTER TABLE LEAD
    ADD CONSTRAINT DF_LEAD_DATA_ULTIMA_ALTERACAO DEFAULT GETDATE() FOR DATA_ULTIMA_ALTERACAO
GO

ALTER TABLE LEAD
    ADD CONSTRAINT DF_LEAD_TIPO DEFAULT 'PROSPECT' FOR TIPO
GO

ALTER TABLE LEAD
    ADD CONSTRAINT DF_LEAD_QUALIDADE DEFAULT 0 FOR QUALIDADE
GO

ALTER TABLE LEAD
    ADD CONSTRAINT DF_LEAD_NOME DEFAULT '' FOR NOME
GO

ALTER TABLE LEAD
    ADD CONSTRAINT DF_LEAD_CNPJ DEFAULT '' FOR CNPJ
GO

ALTER TABLE LEAD
    ADD CONSTRAINT DF_LEAD_CPF DEFAULT '' FOR CPF
GO

ALTER TABLE LEAD
    ADD CONSTRAINT DF_LEAD_TELEFONE DEFAULT '' FOR TELEFONE
GO

ALTER TABLE LEAD
    ADD CONSTRAINT DF_LEAD_EMAIL DEFAULT '' FOR EMAIL
GO

ALTER TABLE LEAD
    ADD CONSTRAINT DF_LEAD_FONTE DEFAULT '' FOR FONTE
GO

ALTER TABLE LEAD
    ADD CONSTRAINT DF_LEAD_ANOTACOES DEFAULT '' FOR ANOTACOES
GO

ALTER TABLE LEAD
    ADD CONSTRAINT DF_LEAD_DELETED DEFAULT 0 FOR DELETED
GO

CREATE UNIQUE NONCLUSTERED INDEX UC_LEAD_ID_CLIENTE
    ON LEAD(ID_CLIENTE)
    WHERE ID_CLIENTE IS NOT NULL
GO

CREATE NONCLUSTERED INDEX IX_LEAD_DELETED
    ON LEAD (DELETED)
GO

CREATE NONCLUSTERED INDEX IX_LEAD_ID_DELETED
    ON LEAD (ID, DELETED)
GO

